# Generated by Django 3.0.6 on 2020-05-28 17:02

from django.db import migrations, models
import music_publisher.validators


class Migration(migrations.Migration):

    dependencies = [
        ('music_publisher', '0004_auto_20200520_1335'),
    ]

    operations = [
        migrations.AddField(
            model_name='work',
            name='_work_id',
            field=models.CharField(blank=True, editable=False, max_length=14, null=True, unique=True, validators=[music_publisher.validators.CWRFieldValidator('name')], verbose_name='Work ID'),
        ),
    ]
