# Generated by Django 3.0.8 on 2020-07-10 10:43

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('music_publisher', '0008_auto_20200708_1318'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='originalpublishingagreement',
            options={'managed': False},
        ),
    ]
